@@ -119,8 +119,10 @@ QConnectedReplicaImplementation::~QConnectedReplicaImplementation()
         sendCommand();
     }
     for (auto prop : m_propertyStorage) {
-        if (prop.canConvert<QObject*>())
-            prop.value<QObject *>()->deleteLater();
+        if (prop.canConvert<QObject*>()) {
+            if (auto o = prop.value<QObject*>())
+                o->deleteLater();
+        }
     }
 }
 
@@ -281,7 +283,7 @@ void QRemoteObjectReplicaImplementation::setDynamicProperties(QVariantList &&val
 void QConnectedReplicaImplementation::setDynamicProperties(QVariantList &&values)
 {
     QRemoteObjectReplicaImplementation::setDynamicProperties(std::move(values));
-    for (QRemoteObjectReplica *obj : qExchange(m_parentsNeedingConnect, {}))
+    for (QRemoteObjectReplica *obj : std::exchange(m_parentsNeedingConnect, {}))
         configurePrivate(obj);
 
     Q_ASSERT(m_state.loadAcquire() < QRemoteObjectReplica::Valid);
@@ -481,8 +483,12 @@ void QConnectedReplicaImplementation::setDisconnected()
     for (const int index : childIndices()) {
         auto pointerToQObject = qvariant_cast<QObject *>(getProperty(index));
         auto child = qobject_cast<QRemoteObjectReplica *>(pointerToQObject);
-        if (child)
-            static_cast<QConnectedReplicaImplementation *>(child->d_impl.data())->setDisconnected();
+        if (child) {
+            QConnectedReplicaImplementation *childReplicaImplData
+                    = static_cast<QConnectedReplicaImplementation *>(child->d_impl.data());
+            if (childReplicaImplData && !childReplicaImplData->connectionToSource.isNull())
+                childReplicaImplData->setDisconnected();
+        }
     }
 }
 
@@ -767,10 +773,9 @@ bool QRemoteObjectReplica::isInitialized() const
 }
 
 /*!
-    Returns \c true if this replica has been initialized with data from the
-    \l {Source} object.  Returns \c false otherwise.
+    Returns the current \l {QRemoteObjectReplica::State}{state} of the replica.
 
-    \sa isInitialized()
+    \sa isInitialized
 */
 QRemoteObjectReplica::State QRemoteObjectReplica::state() const
 {
